@@ -3,14 +3,12 @@ import os
 import sys
 import webbrowser
 from os import isatty
-from typing import List, Sequence, Optional, Iterable
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Iterable, List, Optional, Sequence
 
 # import for nuitka
 # noinspection PyUnresolvedReferences
 import sqlalchemy.sql.default_comparator  # noqa: F401
 import typer
-
 from twbm.bookmarks import Bookmarks, check_tags, clean_tags, parse_tags
 from twbm.buku import BukuDb, edit_rec
 from twbm.db.dal import DAL, Bookmark
@@ -222,7 +220,7 @@ def search(
     Tags must be specified as comma separated list without blanks.
     Correct FTS search syntax: https://www.sqlite.org/fts5.html chapter 3.
 
-    Example:\n
+    Examples:\n
         twbm search 'security "single-page"'\n
         twbm search '"https://securit" *'\n
         twbm search '^security'\n
@@ -230,18 +228,20 @@ def search(
         twbm search 'security NOT keycloak'\n
         twbm search -t tag1,tag2 -n notag1 <searchquery>\n
         twbm search -e tag1,tag2\n
-        twbm search xxxxx | twbm update -t x (interactive selection)\n
+
+        # Interactiv select and pipe result downstream for processing         :
+        twbm search xxxxx | twbm update -t x\n
+
+        # Open all matching sites non-interactively                           :
+        twbm search poker --np | twbm open\n
+
 
     \nCommands in interactive mode:\n
         <n1> <n2>:      opens selection in browser\n
         p <n1> <n1>:    prints corresponding id-list of selection\n
         p:              prints all ids\n
         d <n1> <n1>:    delete selection\n
-
-            p <n1> <n2>:    print id-list of selection
-            p:              print all ids
-            d <n1> <n2>:    delete selection
-            h:              help
+        h:              help\n
     """
     if tags_prefix is not None:
         if tags_all is None:
@@ -280,18 +280,32 @@ def search(
 
 @app.command()
 def delete(
-    # ctx: typer.Context,
-    id_: int = typer.Argument(..., help="id to delete"),
+    # id_: int = typer.Argument(..., help="id to delete"),
+    ids: str = typer.Argument(None, help="list of ids, separated by comma, no blanks"),
     verbose: bool = typer.Option(False, "-v", "--verbose"),
 ):
+    """Delete search results in descending order of DB index."""
     if verbose:
         typer.echo(f"Using DB: {config.twbm_db_url}", err=True)
 
-    # use buku because of DB compactdb
-    with DAL(env_config=config) as dal:
-        bm = dal.get_bookmark_by_id(id_=id_)
-        show_bms((bm,))
-    _ = BukuDb(dbfile=config.dbfile).delete_rec(index=id_, delay_commit=False)
+    # Gotcha: running from IDE looks like pipe, comment out for testing
+    is_pipe = not isatty(sys.stdin.fileno())
+
+    if is_pipe:
+        ids = sys.stdin.readline()
+
+    try:
+        id_list = [int(x.strip()) for x in ids.split(",")]
+    except ValueError:
+        typer.secho(f"-E- Wrong input format.", fg=typer.colors.RED, err=True)
+        raise typer.Abort()
+
+    for id_ in sorted(id_list, reverse=True):
+        # use buku because of DB compactdb
+        with DAL(env_config=config) as dal:
+            bm = dal.get_bookmark_by_id(id_=id_)
+            show_bms((bm,))
+        _ = BukuDb(dbfile=config.dbfile).delete_rec(index=id_, delay_commit=False)
 
 
 @app.command()
@@ -299,7 +313,9 @@ def update(
     # ctx: typer.Context,
     ids: str = typer.Argument(None, help="list of ids, separated by comma, no blanks"),
     tags: str = typer.Option(None, "-t", "--tags", help="add tags to taglist"),
-    tags_not: str = typer.Option(None, "-n", "--tags", help="remove tags from taglist"),
+    tags_not: str = typer.Option(
+        None, "-n", "--ntags", help="remove tags from taglist"
+    ),
     force: bool = typer.Option(
         False, "-f", "--force", help="overwrite taglist with tags"
     ),
@@ -323,7 +339,7 @@ def update(
     if tags_not is not None:
         tags_not = tags_not.lower().replace(" ", "").split(",")  # type: ignore
 
-    # Gotcha: running from IDE looks like pipe
+    # # Gotcha: running from IDE looks like pipe, comment out for testing
     is_pipe = not isatty(sys.stdin.fileno())
 
     if is_pipe:
@@ -358,7 +374,7 @@ def open(
     if verbose:
         typer.echo(f"Using DB: {config.twbm_db_url}", err=True)
 
-    # Gotcha: running from IDE looks like pipe
+    # Gotcha: running from IDE looks like pipe, comment out for testing
     is_pipe = not isatty(sys.stdin.fileno())
 
     if is_pipe:
@@ -404,14 +420,13 @@ def add(
 
     Provide URL (required) and tags (optional) as parameters.
 
-    Example:
-        # Adding URL
-        twbm add https://www.google.com tag1, tag2 --title "<title>"
+    Example:\n
+        twbm add https://www.google.com tag1, tag2 --title "<title>"\n
 
-        # Adding URI to local files (uses platform standard to open file)
+        # Adding URI to local files (uses platform standard to open file)     :
         twmb add '$HOME/vimwiki/e4m/poker-points.png' --title 'Poker Points'
 
-        # Adding shell commands as URI
+        # Adding shell commands as URI                                        :
         twbm add "shell::vim +/'# SqlAlchemy' sql.md" shell,sql,doc --title 'sqlalchemy snippets'
     """
     if verbose:
